#
# spec file for package deepin-screen-recorder
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define    procps_version    %(rpm -q --queryformat '%%{VERSION}' procps-devel)

Name:           deepin-screen-recorder
Version:        5.11.6
Release:        3.1
Summary:        Deepin Screen Recorder
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/linuxdeepin/deepin-screen-recorder
Source0:        https://github.com/linuxdeepin/deepin-screen-recorder/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-include-path.patch hillwood@opensuse.org - Add ffmpeg include path
Patch0:         fix-include-path.patch
# PATCH-FIX-UPSTREAM fix-reture-type.patch hillwood@opensuse.org
Patch1:         fix-reture-type.patch
# PATCH-FIX-UPSTREAM add-missing-include-header.patch hillwood@opensuse.org - Missing include a header
Patch2:         add-missing-include-header.patch
# fdupes macro works
Source1:        %{name}-rpmlintrc
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  deepin-dock
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  procps-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dde-dock)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dtkgui) >= 5.0.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(dtkwm)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
%if 0%{?suse_version} > 1500
BuildRequires:  ffmpeg-6-mini-devel
BuildRequires:  pkgconfig(opencv4)
%else
BuildRequires:  pkgconfig(opencv)
%endif
BuildRequires:  (pkgconfig(libavcodec) with pkgconfig(libavcodec) < 61)
BuildRequires:  (pkgconfig(libavformat) with pkgconfig(libavformat) < 61)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
BuildRequires:  pkgconfig(libimagevisualresult)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libv4l1)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xtst)
Recommends:     %{name}-lang
Requires:       byzanz
Requires:       ffmpeg
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
deepin-screen-recorder is free and open source software for screen recording.

%package -n deepin-dock-plugin-screen-recorder
Summary:        The screen recorder plugin of deepin dock
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}
Requires:       deepin-dock

%description -n deepin-dock-plugin-screen-recorder
The deepin screen recorder plugin of deepin dock

%package -n deepin-dock-plugin-shot-start
Summary:        The shot start plugin of deepin dock
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}
Requires:       deepin-dock

%description -n deepin-dock-plugin-shot-start
The shot start of deepin dock

%lang_package

%prep
%autosetup -p1 -n %{name}-%{version}
sed -i '/#include<opencv2/i #include <opencv2/imgproc/types_c.h>' src/utils/pixmergethread.h
%if 0%{?suse_version} > 1500
sed -i 's/dframeworkdbus/dframeworkdbus opencv4/' src/src.pro
%else
sed -i 's/dframeworkdbus/dframeworkdbus opencv/' src/src.pro
%endif
sed -i '/include <X11.extensions.XTest.h>/a #undef min' src/event_monitor.cpp
# sed -i '/#include <iostream>/d;1i #include <iostream>' src/screen_shot_event.cpp
# sed -i '/include <X11.extensions.shape.h>/a #undef None' src/utils.cpp
sed -i 's|/usr/lib|$$LIB_INSTALL_DIR|g' src/dde-dock-plugins/recordtime/recordtime.pro \
src/dde-dock-plugins/shotstart/shotstart.pro
sed -i "s^cat /etc/os-version | grep 'Community'^echo 'Community'^" src/src.pro

%if "%{procps_version}" >= "4.0.0"
sed -i '/find_library/s|procps|proc-2|' src/CMakeLists.txt
%endif

%build
%qmake5 LIB_INSTALL_DIR=%{_libdir} \
        lupdate=/usr/bin/lupdate-qt5 \
        lrelease=/usr/bin/lrelease-qt5
%make_build

%install
%qmake5_install

%fdupes %{buildroot}%{_datadir}

find %{buildroot}%{_datadir}/deepin-manual -name '*.svg' -type f -print -exec chmod -x {} \;
find %{buildroot}%{_datadir}/deepin-manual -name '*.md' -type f -print -exec chmod -x {} \;
chmod -x %{buildroot}%{_datadir}/dbus-1/services/com.deepin.PinScreenShots.service

%suse_update_desktop_file %{name}

%files
%doc README.md CHANGELOG.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/deepin-pin-screenshots
%{_datadir}/applications/*.desktop
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/dbus-1/services/com.deepin.PinScreenShots.service
%{_datadir}/dbus-1/services/com.deepin.ScreenRecorder.service
%{_datadir}/dbus-1/services/com.deepin.Screenshot.service
%{_datadir}/deepin-manual/manual-assets/application/%{name}

%files -n deepin-dock-plugin-screen-recorder
%{_libdir}/dde-dock/plugins/libdeepin-screen-recorder-plugin.so

%files -n deepin-dock-plugin-shot-start
%{_libdir}/dde-dock/plugins/libshot-start-plugin.so
%{_datadir}/glib-2.0/schemas/com.deepin.dde.dock.module.shot-start-plugin.gschema.xml

%files lang
%{_datadir}/%{name}
# %{_datadir}/deepin-pin-screenshots

%changelog
* Fri Oct  4 2024 Hillwood Yang <hillwood@opensuse.org>
- Add add-missing-include-header.patch, need include camview.h in
  3rdparty/libcam/libcam_encoder/mp4.c
* Thu Aug 15 2024 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Tumbleweed: don't use ffmpeg 7 and later
* Fri Aug 26 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.11.6
  * Add event tracking feature
  * Optimize shortcut keys
  * Fix bugs
- Add fix-include-path.patch, add ffmpeg include path
- Add fix-reture-type.patch
* Wed Jun 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.11.2
  * Add a new plugin for deepin dock
  * Use gstreamer backend
  * Optimize wayland support
  * Fix memory leak
  * Fix bugs
* Sun May 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.10.22
  * Fix bugs
* Fri Apr  8 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.10.15
  * Optimize code
  * Add interfaces for OCR and roll screenshot
  * Optimize wayland support
  * Fix bugs
* Sun Jan 30 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15.4
* Sun Jan 30 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.10.9
  * Update documents
  * Fix bugs
* Fri Jul 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.10
  * Fix bugs
  * Add DBus interface for ocr
  * Update translations
* Fri Jun  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Stop owning directories provided by filesystem and other packages
  (every dir should only have one owner) (boo#1184786)
* Tue May  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.3
  * Add a deepin-dock plugin
  * Add user guide documents
  * Fix bugs
- Drop deepin-screen-recorder-qt5.15.patch, merged by upstream
* Thu Feb 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.1
  * Merge deepin-screenshot
  * Update dtk APIs
  * Fix bugs
* Wed Nov 20 2019 Hillwood Yang <hillwood@opensuse.org>
- Drop libqt4-linguist
* Tue Jul  9 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.8.0
  * Fix cannot select window on other screen
  * Fix Can't select window correctly
  * Fix multiple screens cannot be recorded after set window scale
  * Auto pull translation files from transifex
- Fix translations build in Tumbleweed, use libqt4-linguist to workaround
* Sun Mar 24 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.7.7
  * Add displayNumber to fixed that ffmpe will crash if multi-user
    with x11grab display argument :0.0
  * update run depend
  * use DISPLAY directly
  * desktop: add generic name.
* Thu Mar 22 2018 hillwood@opensuse.org
- Update version to 2.7.3
  * Fix tooltip not above on screen-recorder window
  * Support flv format recording
  * Synchronous translations from transifex.com
  * Support deepin-manual newest version
  * Fix error that GIF's content is not complete
  * Fix GIF file break when stop recording less than 2 seconds
  * Fix zero byte mp4 problem
  * Use -vf scale fix "division by 2" error, and now we can use yuv420p pix_fmt
    to make mp4 play on mobile phone
  * Add mkv_framerate and mp4_framerate customize options
  * Don't need append char to gif end since gif exit process is correct now,
    otherwise gif file will break if you stop recording too fast. ;)
  * Synchronous translations.
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 2.6.5.1
  * Add FlatPak support: single instance, keystroke dbus service
  * Add composite warning dialog when window manager not support composite
  * Fix GIF record area is not correctly under HiDPI
  * Install dbus service
  Fix bugs:
  * Bypass window manager
  * Flatpak: No composite warning dialog
  * Hidpi: Gif record area calculated wrong
* Mon Nov  6 2017 hillwood@opensuse.org
- Cleanup spec
- Add Group tag
- Split language package
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
